"""
Bar chart demo with pairs of bars grouped for easy comparison.
"""
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.backends.backend_pdf import PdfPages
import matplotlib
matplotlib.rcParams.update({'font.size': 16})
matplotlib.rc('text', usetex = True)


n_groups = 3

mean_doc = (0.28541176,0.34749929,0.36708894)
std_doc = (0.04022142,0.02807599,0.0184885)

mean_query = (0.19912382,0.25785727,0.54301891)
std_query = (0.06410082,0.07148185,0.09922599)

mean_doc_query = (0.21756406,0.26645482,0.51598112)
std_doc_query = (0.07019297,0.08157054,0.12862956)

label = (4,3,2)

fig, ax = plt.subplots()

index = np.arange(n_groups)
bar_width = 0.2

opacity = 0.5
error_config = {'ecolor': '0.3', 'elinewidth' : '2', 'capsize' : '2'}

rects1 = plt.bar(index+0.5*bar_width, mean_doc, bar_width,
		 alpha=opacity,
		 color='b',
		 yerr=std_doc,
		 error_kw=error_config,
		 label='NPM[doc]')

rects2 = plt.bar(index + 1.5*bar_width, mean_query, bar_width,
		 alpha=opacity,
		 color='r',
		 yerr=std_query,
		 error_kw=error_config,
		 label='NPM[query]')

rects3 = plt.bar(index + 2.5*bar_width, mean_doc_query, bar_width,
                 alpha=opacity,
                 color='g',
                 yerr=std_doc_query,
                 error_kw=error_config,
                 label='NPM[doc+query]')

plt.xlabel('Passage Size',fontsize=20)
plt.ylabel('Fusion Weight',fontsize=20)
#plt.title('Scores by group and gender')
plt.xticks(index + 2*bar_width, ('50', '150', r'$\infty$', ),fontsize=18,style='italic')
plt.ylim(ymax=0.7, ymin=0.0)
#plt.xlim(xmax=60, xmin=10)
plt.legend(loc=2)
ax.set_yticks([0.05*i for i in xrange(15)], minor=True)
ax.set_yticklabels([str(10*i) + '\%' for i in xrange(15)])
plt.grid(b=True, which='minor', color='k', linestyle='--',alpha=opacity*0.5)
#ax.set_yticks([0.0], minor=False)
ax.yaxis.grid(b=True, which='major', color='k', linestyle='--')
ax.xaxis.grid(b=True, which='major', color='k', linestyle='--',alpha=opacity)

plt.tight_layout()

fig.savefig('./weight.pdf')
#plt.show()